==> james-project-3.4.0-source-release.zip: james-project-3.4.0/mpt/impl/imap-mailbox/jpa/src/test/java/org/apache/james/mpt/imapmailbox/jpa/JpaConcurrentSessionsTest.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mpt.imapmailbox.jpa;

import org.apache.james.mpt.api.ImapHostSystem;
import org.apache.james.mpt.imapmailbox.jpa.host.JPAHostSystemRule;
import org.apache.james.mpt.imapmailbox.suite.ConcurrentSessions;
import org.junit.Rule;

public class JpaConcurrentSessionsTest extends ConcurrentSessions {
    @Rule
    public JPAHostSystemRule hostSystemRule = new JPAHostSystemRule();

    @Override
    protected ImapHostSystem createImapHostSystem() {
        return hostSystemRule.getHostSystem();
    }

    @Override
    public void testConcurrentFetchResponseITALY() {
    }

    @Override
    public void testConcurrentFetchResponseKOREA() {
    }

    @Override
    public void testConcurrentFetchResponseUS() {
    }
}

==> james-project-3.8.2-source-release.zip: james-project-3.8.2/mpt/impl/imap-mailbox/jpa/src/test/java/org/apache/james/mpt/imapmailbox/jpa/JpaConcurrentSessionsTest.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mpt.imapmailbox.jpa;

import org.apache.james.mpt.api.ImapHostSystem;
import org.apache.james.mpt.imapmailbox.jpa.host.JPAHostSystemExtension;
import org.apache.james.mpt.imapmailbox.suite.ConcurrentSessions;
import org.junit.jupiter.api.extension.RegisterExtension;

public class JpaConcurrentSessionsTest extends ConcurrentSessions {
    @RegisterExtension
    public JPAHostSystemExtension hostSystemExtension = new JPAHostSystemExtension();

    @Override
    protected ImapHostSystem createImapHostSystem() {
        return hostSystemExtension.getHostSystem();
    }

    @Override
    public void testConcurrentFetchResponseITALY() {
    }

    @Override
    public void testConcurrentFetchResponseKOREA() {
    }

    @Override
    public void testConcurrentFetchResponseUS() {
    }
}
